@@ -1,11 +1,12 @@
 # vim: set ft=perl ts=8 sts=2 sw=2 tw=100 et :
 use strict;
 use warnings;
-use 5.016;
+use 5.020;
+use experimental qw(signatures postderef);
+use if "$]" >= 5.022, experimental => 're_strict';
 no if "$]" >= 5.031009, feature => 'indirect';
 no if "$]" >= 5.033001, feature => 'multidimensional';
 no if "$]" >= 5.033006, feature => 'bareword_filehandles';
-use if "$]" >= 5.022, experimental => 're_strict';
 use open ':std', ':encoding(UTF-8)'; # force stdin, stdout, stderr into utf8
 
 use Test::More;
@@ -26,15 +27,13 @@ BEGIN {
   note '';
 }
 
-sub acceptance_tests {
-  my (%options) = @_;
-
+sub acceptance_tests (%options) {
   local $Test::Builder::Level = $Test::Builder::Level + 1;
   my $accepter = Test::JSON::Schema::Acceptance->new(
     include_optional => 1,
     verbose => 1,
     test_schemas => -d '.git' || $ENV{AUTHOR_TESTING},
-    %{$options{acceptance}},
+    $options{acceptance}->%*,
     $ENV{TEST_DIR} ? (test_dir => $ENV{TEST_DIR})
       : $ENV{TEST_PREFIXDIR} ? (test_dir => path($ENV{TEST_PREFIXDIR}, 'tests', $options{acceptance}{specification})) : (),
   );
@@ -42,14 +41,13 @@ sub acceptance_tests {
       test_dir => $accepter->test_dir->child($options{acceptance}{test_subdir}))
     if not $ENV{TEST_DIR} and $options{acceptance}{test_subdir};
 
-  my $js = JSON::Schema::Modern->new(%{$options{evaluator}});
-  my $js_short_circuit = $ENV{NO_SHORT_CIRCUIT} || JSON::Schema::Modern->new(%{$options{evaluator}}, short_circuit => 1);
+  my $js = JSON::Schema::Modern->new($options{evaluator}->%*);
+  my $js_short_circuit = $ENV{NO_SHORT_CIRCUIT} || JSON::Schema::Modern->new($options{evaluator}->%*, short_circuit => 1);
 
   my $encoder = JSON::MaybeXS->new(allow_nonref => 1, utf8 => 0, convert_blessed => 1, canonical => 1, pretty => 1);
   $encoder->indent_length(2) if $encoder->can('indent_length');
 
-  my $add_resource = sub {
-    my ($uri, $schema) = @_;
+  my $add_resource = sub ($uri, $schema) {
     try {
       # suppress warnings from parsing remotes/* intended for draft <= 7 with 'definitions'
       local $SIG{__WARN__} = sub {
@@ -64,8 +62,7 @@ sub acceptance_tests {
   };
 
   $accepter->acceptance(
-    validate_data => sub {
-      my ($schema, $instance_data) = @_;
+    validate_data => sub ($schema, $instance_data) {
       my $result = $js->evaluate($instance_data, $schema);
       my $result_short = $ENV{NO_SHORT_CIRCUIT} || $js_short_circuit->evaluate($instance_data, $schema);
 
@@ -87,14 +84,14 @@ sub acceptance_tests {
             grep +($_->{error} =~ /^EXCEPTION/
                 && $_->{error} !~ /but short_circuit is enabled/            # unevaluated*
                 && $_->{error} !~ /(max|min)imum value is not a number$/),  # optional/bignum.json
-              @{$r->TO_JSON->{errors}};
+              $r->TO_JSON->{errors}->@*;
       }
 
       $result;
     },
     add_resource => $add_resource,
     @ARGV ? (tests => { file => \@ARGV }) : (),
-    %{$options{test} // {}},
+    ($options{test} // {})->%*,
   );
 
   memory_cycle_ok($js, 'no leaks in the main evaluator object');
